@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Optional, Union
+from typing import TYPE_CHECKING, Any
 
 from pydantic import Field
 
@@ -31,47 +31,45 @@ class SendMessage(TelegramMethod[Message]):
     """Unique identifier for the target chat or username of the target channel (in the format :code:`@channelusername`)"""
     text: str
     """Text of the message to be sent, 1-4096 characters after entities parsing"""
-    business_connection_id: Optional[str] = None
+    business_connection_id: str | None = None
     """Unique identifier of the business connection on behalf of which the message will be sent"""
-    message_thread_id: Optional[int] = None
-    """Unique identifier for the target message thread (topic) of the forum; for forum supergroups only"""
-    direct_messages_topic_id: Optional[int] = None
+    message_thread_id: int | None = None
+    """Unique identifier for the target message thread (topic) of a forum; for forum supergroups and private chats of bots with forum topic mode enabled only"""
+    direct_messages_topic_id: int | None = None
     """Identifier of the direct messages topic to which the message will be sent; required if the message is sent to a direct messages chat"""
-    parse_mode: Optional[Union[str, Default]] = Default("parse_mode")
+    parse_mode: str | Default | None = Default("parse_mode")
     """Mode for parsing entities in the message text. See `formatting options <https://core.telegram.org/bots/api#formatting-options>`_ for more details."""
-    entities: Optional[list[MessageEntity]] = None
+    entities: list[MessageEntity] | None = None
     """A JSON-serialized list of special entities that appear in message text, which can be specified instead of *parse_mode*"""
-    link_preview_options: Optional[Union[LinkPreviewOptions, Default]] = Default("link_preview")
+    link_preview_options: LinkPreviewOptions | Default | None = Default("link_preview")
     """Link preview generation options for the message"""
-    disable_notification: Optional[bool] = None
+    disable_notification: bool | None = None
     """Sends the message `silently <https://telegram.org/blog/channels-2-0#silent-messages>`_. Users will receive a notification with no sound."""
-    protect_content: Optional[Union[bool, Default]] = Default("protect_content")
+    protect_content: bool | Default | None = Default("protect_content")
     """Protects the contents of the sent message from forwarding and saving"""
-    allow_paid_broadcast: Optional[bool] = None
+    allow_paid_broadcast: bool | None = None
     """Pass :code:`True` to allow up to 1000 messages per second, ignoring `broadcasting limits <https://core.telegram.org/bots/faq#how-can-i-message-all-of-my-bot-39s-subscribers-at-once>`_ for a fee of 0.1 Telegram Stars per message. The relevant Stars will be withdrawn from the bot's balance"""
-    message_effect_id: Optional[str] = None
+    message_effect_id: str | None = None
     """Unique identifier of the message effect to be added to the message; for private chats only"""
-    suggested_post_parameters: Optional[SuggestedPostParameters] = None
+    suggested_post_parameters: SuggestedPostParameters | None = None
     """A JSON-serialized object containing the parameters of the suggested post to send; for direct messages chats only. If the message is sent as a reply to another suggested post, then that suggested post is automatically declined."""
-    reply_parameters: Optional[ReplyParameters] = None
+    reply_parameters: ReplyParameters | None = None
     """Description of the message to reply to"""
-    reply_markup: Optional[ReplyMarkupUnion] = None
+    reply_markup: ReplyMarkupUnion | None = None
     """Additional interface options. A JSON-serialized object for an `inline keyboard <https://core.telegram.org/bots/features#inline-keyboards>`_, `custom reply keyboard <https://core.telegram.org/bots/features#keyboards>`_, instructions to remove a reply keyboard or to force a reply from the user"""
-    allow_sending_without_reply: Optional[bool] = Field(
-        None, json_schema_extra={"deprecated": True}
-    )
+    allow_sending_without_reply: bool | None = Field(None, json_schema_extra={"deprecated": True})
     """Pass :code:`True` if the message should be sent even if the specified replied-to message is not found
 
 .. deprecated:: API:7.0
    https://core.telegram.org/bots/api-changelog#december-29-2023"""
-    disable_web_page_preview: Optional[Union[bool, Default]] = Field(
+    disable_web_page_preview: bool | Default | None = Field(
         Default("link_preview_is_disabled"), json_schema_extra={"deprecated": True}
     )
     """Disables link previews for links in this message
 
 .. deprecated:: API:7.0
    https://core.telegram.org/bots/api-changelog#december-29-2023"""
-    reply_to_message_id: Optional[int] = Field(None, json_schema_extra={"deprecated": True})
+    reply_to_message_id: int | None = Field(None, json_schema_extra={"deprecated": True})
     """If the message is a reply, ID of the original message
 
 .. deprecated:: API:7.0
@@ -86,26 +84,22 @@ class SendMessage(TelegramMethod[Message]):
             *,
             chat_id: ChatIdUnion,
             text: str,
-            business_connection_id: Optional[str] = None,
-            message_thread_id: Optional[int] = None,
-            direct_messages_topic_id: Optional[int] = None,
-            parse_mode: Optional[Union[str, Default]] = Default("parse_mode"),
-            entities: Optional[list[MessageEntity]] = None,
-            link_preview_options: Optional[Union[LinkPreviewOptions, Default]] = Default(
-                "link_preview"
-            ),
-            disable_notification: Optional[bool] = None,
-            protect_content: Optional[Union[bool, Default]] = Default("protect_content"),
-            allow_paid_broadcast: Optional[bool] = None,
-            message_effect_id: Optional[str] = None,
-            suggested_post_parameters: Optional[SuggestedPostParameters] = None,
-            reply_parameters: Optional[ReplyParameters] = None,
-            reply_markup: Optional[ReplyMarkupUnion] = None,
-            allow_sending_without_reply: Optional[bool] = None,
-            disable_web_page_preview: Optional[Union[bool, Default]] = Default(
-                "link_preview_is_disabled"
-            ),
-            reply_to_message_id: Optional[int] = None,
+            business_connection_id: str | None = None,
+            message_thread_id: int | None = None,
+            direct_messages_topic_id: int | None = None,
+            parse_mode: str | Default | None = Default("parse_mode"),
+            entities: list[MessageEntity] | None = None,
+            link_preview_options: LinkPreviewOptions | Default | None = Default("link_preview"),
+            disable_notification: bool | None = None,
+            protect_content: bool | Default | None = Default("protect_content"),
+            allow_paid_broadcast: bool | None = None,
+            message_effect_id: str | None = None,
+            suggested_post_parameters: SuggestedPostParameters | None = None,
+            reply_parameters: ReplyParameters | None = None,
+            reply_markup: ReplyMarkupUnion | None = None,
+            allow_sending_without_reply: bool | None = None,
+            disable_web_page_preview: bool | Default | None = Default("link_preview_is_disabled"),
+            reply_to_message_id: int | None = None,
             **__pydantic_kwargs: Any,
         ) -> None:
             # DO NOT EDIT MANUALLY!!!
