@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Optional, Union
+from typing import TYPE_CHECKING, Any
 
 from pydantic import Field
 
@@ -33,54 +33,52 @@ class SendPoll(TelegramMethod[Message]):
     """Poll question, 1-300 characters"""
     options: list[InputPollOptionUnion]
     """A JSON-serialized list of 2-12 answer options"""
-    business_connection_id: Optional[str] = None
+    business_connection_id: str | None = None
     """Unique identifier of the business connection on behalf of which the message will be sent"""
-    message_thread_id: Optional[int] = None
-    """Unique identifier for the target message thread (topic) of the forum; for forum supergroups only"""
-    question_parse_mode: Optional[Union[str, Default]] = Default("parse_mode")
+    message_thread_id: int | None = None
+    """Unique identifier for the target message thread (topic) of a forum; for forum supergroups and private chats of bots with forum topic mode enabled only"""
+    question_parse_mode: str | Default | None = Default("parse_mode")
     """Mode for parsing entities in the question. See `formatting options <https://core.telegram.org/bots/api#formatting-options>`_ for more details. Currently, only custom emoji entities are allowed"""
-    question_entities: Optional[list[MessageEntity]] = None
+    question_entities: list[MessageEntity] | None = None
     """A JSON-serialized list of special entities that appear in the poll question. It can be specified instead of *question_parse_mode*"""
-    is_anonymous: Optional[bool] = None
+    is_anonymous: bool | None = None
     """:code:`True`, if the poll needs to be anonymous, defaults to :code:`True`"""
-    type: Optional[str] = None
+    type: str | None = None
     """Poll type, 'quiz' or 'regular', defaults to 'regular'"""
-    allows_multiple_answers: Optional[bool] = None
+    allows_multiple_answers: bool | None = None
     """:code:`True`, if the poll allows multiple answers, ignored for polls in quiz mode, defaults to :code:`False`"""
-    correct_option_id: Optional[int] = None
+    correct_option_id: int | None = None
     """0-based identifier of the correct answer option, required for polls in quiz mode"""
-    explanation: Optional[str] = None
+    explanation: str | None = None
     """Text that is shown when a user chooses an incorrect answer or taps on the lamp icon in a quiz-style poll, 0-200 characters with at most 2 line feeds after entities parsing"""
-    explanation_parse_mode: Optional[Union[str, Default]] = Default("parse_mode")
+    explanation_parse_mode: str | Default | None = Default("parse_mode")
     """Mode for parsing entities in the explanation. See `formatting options <https://core.telegram.org/bots/api#formatting-options>`_ for more details."""
-    explanation_entities: Optional[list[MessageEntity]] = None
+    explanation_entities: list[MessageEntity] | None = None
     """A JSON-serialized list of special entities that appear in the poll explanation. It can be specified instead of *explanation_parse_mode*"""
-    open_period: Optional[int] = None
+    open_period: int | None = None
     """Amount of time in seconds the poll will be active after creation, 5-600. Can't be used together with *close_date*."""
-    close_date: Optional[DateTimeUnion] = None
+    close_date: DateTimeUnion | None = None
     """Point in time (Unix timestamp) when the poll will be automatically closed. Must be at least 5 and no more than 600 seconds in the future. Can't be used together with *open_period*."""
-    is_closed: Optional[bool] = None
+    is_closed: bool | None = None
     """Pass :code:`True` if the poll needs to be immediately closed. This can be useful for poll preview."""
-    disable_notification: Optional[bool] = None
+    disable_notification: bool | None = None
     """Sends the message `silently <https://telegram.org/blog/channels-2-0#silent-messages>`_. Users will receive a notification with no sound."""
-    protect_content: Optional[Union[bool, Default]] = Default("protect_content")
+    protect_content: bool | Default | None = Default("protect_content")
     """Protects the contents of the sent message from forwarding and saving"""
-    allow_paid_broadcast: Optional[bool] = None
+    allow_paid_broadcast: bool | None = None
     """Pass :code:`True` to allow up to 1000 messages per second, ignoring `broadcasting limits <https://core.telegram.org/bots/faq#how-can-i-message-all-of-my-bot-39s-subscribers-at-once>`_ for a fee of 0.1 Telegram Stars per message. The relevant Stars will be withdrawn from the bot's balance"""
-    message_effect_id: Optional[str] = None
+    message_effect_id: str | None = None
     """Unique identifier of the message effect to be added to the message; for private chats only"""
-    reply_parameters: Optional[ReplyParameters] = None
+    reply_parameters: ReplyParameters | None = None
     """Description of the message to reply to"""
-    reply_markup: Optional[ReplyMarkupUnion] = None
+    reply_markup: ReplyMarkupUnion | None = None
     """Additional interface options. A JSON-serialized object for an `inline keyboard <https://core.telegram.org/bots/features#inline-keyboards>`_, `custom reply keyboard <https://core.telegram.org/bots/features#keyboards>`_, instructions to remove a reply keyboard or to force a reply from the user"""
-    allow_sending_without_reply: Optional[bool] = Field(
-        None, json_schema_extra={"deprecated": True}
-    )
+    allow_sending_without_reply: bool | None = Field(None, json_schema_extra={"deprecated": True})
     """Pass :code:`True` if the message should be sent even if the specified replied-to message is not found
 
 .. deprecated:: API:7.0
    https://core.telegram.org/bots/api-changelog#december-29-2023"""
-    reply_to_message_id: Optional[int] = Field(None, json_schema_extra={"deprecated": True})
+    reply_to_message_id: int | None = Field(None, json_schema_extra={"deprecated": True})
     """If the message is a reply, ID of the original message
 
 .. deprecated:: API:7.0
@@ -96,28 +94,28 @@ class SendPoll(TelegramMethod[Message]):
             chat_id: ChatIdUnion,
             question: str,
             options: list[InputPollOptionUnion],
-            business_connection_id: Optional[str] = None,
-            message_thread_id: Optional[int] = None,
-            question_parse_mode: Optional[Union[str, Default]] = Default("parse_mode"),
-            question_entities: Optional[list[MessageEntity]] = None,
-            is_anonymous: Optional[bool] = None,
-            type: Optional[str] = None,
-            allows_multiple_answers: Optional[bool] = None,
-            correct_option_id: Optional[int] = None,
-            explanation: Optional[str] = None,
-            explanation_parse_mode: Optional[Union[str, Default]] = Default("parse_mode"),
-            explanation_entities: Optional[list[MessageEntity]] = None,
-            open_period: Optional[int] = None,
-            close_date: Optional[DateTimeUnion] = None,
-            is_closed: Optional[bool] = None,
-            disable_notification: Optional[bool] = None,
-            protect_content: Optional[Union[bool, Default]] = Default("protect_content"),
-            allow_paid_broadcast: Optional[bool] = None,
-            message_effect_id: Optional[str] = None,
-            reply_parameters: Optional[ReplyParameters] = None,
-            reply_markup: Optional[ReplyMarkupUnion] = None,
-            allow_sending_without_reply: Optional[bool] = None,
-            reply_to_message_id: Optional[int] = None,
+            business_connection_id: str | None = None,
+            message_thread_id: int | None = None,
+            question_parse_mode: str | Default | None = Default("parse_mode"),
+            question_entities: list[MessageEntity] | None = None,
+            is_anonymous: bool | None = None,
+            type: str | None = None,
+            allows_multiple_answers: bool | None = None,
+            correct_option_id: int | None = None,
+            explanation: str | None = None,
+            explanation_parse_mode: str | Default | None = Default("parse_mode"),
+            explanation_entities: list[MessageEntity] | None = None,
+            open_period: int | None = None,
+            close_date: DateTimeUnion | None = None,
+            is_closed: bool | None = None,
+            disable_notification: bool | None = None,
+            protect_content: bool | Default | None = Default("protect_content"),
+            allow_paid_broadcast: bool | None = None,
+            message_effect_id: str | None = None,
+            reply_parameters: ReplyParameters | None = None,
+            reply_markup: ReplyMarkupUnion | None = None,
+            allow_sending_without_reply: bool | None = None,
+            reply_to_message_id: int | None = None,
             **__pydantic_kwargs: Any,
         ) -> None:
             # DO NOT EDIT MANUALLY!!!
