@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Union
+from typing import TypeAlias
 
 from .input_media_animation import InputMediaAnimation
 from .input_media_audio import InputMediaAudio
@@ -8,6 +8,6 @@ from .input_media_document import InputMediaDocument
 from .input_media_photo import InputMediaPhoto
 from .input_media_video import InputMediaVideo
 
-InputMediaUnion = Union[
-    InputMediaAnimation, InputMediaDocument, InputMediaAudio, InputMediaPhoto, InputMediaVideo
-]
+InputMediaUnion: TypeAlias = (
+    InputMediaAnimation | InputMediaDocument | InputMediaAudio | InputMediaPhoto | InputMediaVideo
+)
