@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Union
+from typing import TypeAlias
 
 from .input_contact_message_content import InputContactMessageContent
 from .input_invoice_message_content import InputInvoiceMessageContent
@@ -8,10 +8,10 @@ from .input_location_message_content import InputLocationMessageContent
 from .input_text_message_content import InputTextMessageContent
 from .input_venue_message_content import InputVenueMessageContent
 
-InputMessageContentUnion = Union[
-    InputTextMessageContent,
-    InputLocationMessageContent,
-    InputVenueMessageContent,
-    InputContactMessageContent,
-    InputInvoiceMessageContent,
-]
+InputMessageContentUnion: TypeAlias = (
+    InputTextMessageContent
+    | InputLocationMessageContent
+    | InputVenueMessageContent
+    | InputContactMessageContent
+    | InputInvoiceMessageContent
+)
