@@ -1,6 +1,6 @@
-from typing import Union
+from typing import TypeAlias
 
 from .input_story_content_photo import InputStoryContentPhoto
 from .input_story_content_video import InputStoryContentVideo
 
-InputStoryContentUnion = Union[InputStoryContentPhoto, InputStoryContentVideo]
+InputStoryContentUnion: TypeAlias = InputStoryContentPhoto | InputStoryContentVideo
