@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from typing import Union
+from typing import TypeAlias
 
 from .menu_button_commands import MenuButtonCommands
 from .menu_button_default import MenuButtonDefault
 from .menu_button_web_app import MenuButtonWebApp
 
-MenuButtonUnion = Union[MenuButtonCommands, MenuButtonWebApp, MenuButtonDefault]
+MenuButtonUnion: TypeAlias = MenuButtonCommands | MenuButtonWebApp | MenuButtonDefault
