@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from typing import Union
+from typing import TypeAlias
 
 from .paid_media_photo import PaidMediaPhoto
 from .paid_media_preview import PaidMediaPreview
 from .paid_media_video import PaidMediaVideo
 
-PaidMediaUnion = Union[PaidMediaPreview, PaidMediaPhoto, PaidMediaVideo]
+PaidMediaUnion: TypeAlias = PaidMediaPreview | PaidMediaPhoto | PaidMediaVideo
