@@ -1,4 +1,4 @@
-from typing import Union
+from typing import TypeAlias
 
 from .chat_member_administrator import ChatMemberAdministrator
 from .chat_member_banned import ChatMemberBanned
@@ -7,11 +7,11 @@ from .chat_member_member import ChatMemberMember
 from .chat_member_owner import ChatMemberOwner
 from .chat_member_restricted import ChatMemberRestricted
 
-ResultChatMemberUnion = Union[
-    ChatMemberOwner,
-    ChatMemberAdministrator,
-    ChatMemberMember,
-    ChatMemberRestricted,
-    ChatMemberLeft,
-    ChatMemberBanned,
-]
+ResultChatMemberUnion: TypeAlias = (
+    ChatMemberOwner
+    | ChatMemberAdministrator
+    | ChatMemberMember
+    | ChatMemberRestricted
+    | ChatMemberLeft
+    | ChatMemberBanned
+)
