@@ -1,4 +1,4 @@
-from typing import Union
+from typing import TypeAlias
 
 from .story_area_type_link import StoryAreaTypeLink
 from .story_area_type_location import StoryAreaTypeLocation
@@ -6,10 +6,10 @@ from .story_area_type_suggested_reaction import StoryAreaTypeSuggestedReaction
 from .story_area_type_unique_gift import StoryAreaTypeUniqueGift
 from .story_area_type_weather import StoryAreaTypeWeather
 
-StoryAreaTypeUnion = Union[
-    StoryAreaTypeLocation,
-    StoryAreaTypeSuggestedReaction,
-    StoryAreaTypeLink,
-    StoryAreaTypeWeather,
-    StoryAreaTypeUniqueGift,
-]
+StoryAreaTypeUnion: TypeAlias = (
+    StoryAreaTypeLocation
+    | StoryAreaTypeSuggestedReaction
+    | StoryAreaTypeLink
+    | StoryAreaTypeWeather
+    | StoryAreaTypeUniqueGift
+)
